==> react-batch-autocomplete-lib-1.0.7.tgz: package/src/stories/Select.stories.js <==
import React, { Fragment, useState } from "react";
import { storiesOf } from "@storybook/react";
import { ReactBatchAutocomplete } from "../component/autocomplete";

const stories = storiesOf("App ts", module);

stories.add("Test", () => {
  const apikey = 'rYGL9L8GzgASw3Qq8AxFbclLsXmCrfbVkJ56kOF9'
  const domainServer = 'https://api.dev.batchdata.com/api/v1/address/autocomplete'
  const [recentSearch, setRecentSearch] = useState([
    {"name": '8300 Apple'},
    {"name": 'Apple St.'},
    {"name": '89001 Alamo'},
    {"name": '58651 Rhame'}
  ])

  const handleError = (e) => {
    console.log('Error while searching: ',e);
  }

  const suggestionList = (data) => {
    console.log('Suggetion List: ', data);
  }

  const onSelect = (data) => {
    console.log('Seleted item: ', data)
    if (data) {
      let newData = [...recentSearch]
      newData.unshift({name: data?.name})
      newData.pop()
      setRecentSearch(newData)
    }
  }

  const searchElement = <Fragment><div className="auto-wrapper">
  <div className="img-wrap" />
    <div className="text-content">
  </div>
</div></Fragment>

  return (
    <div style={{width:420}}>
      <h2>Batch Service React Autocomplete Lib...</h2>
      <p>Start typing to select address:</p>
      <ReactBatchAutocomplete
      placeholder="Enter your address"
      notFoundText="No results found"
      debounce="700"
      apiKey={apikey}
      domainServer={domainServer}
      recentSearch ={recentSearch}
      handleError={(e) => handleError(e)}
      suggestionList={(data) => suggestionList(data)}
      onSelect={(data) => onSelect(data)}
      displayData="name"
      showNotFound={true}
      take={15}
      fillterType={['address', 'formatted-street', 'zip']}
    />
    </div>
  );
});

==> react-batch-autocomplete-lib-1.0.8.tgz: package/src/stories/Select.stories.js <==
import React, { Fragment, useState } from "react";
import { storiesOf } from "@storybook/react";
import { ReactBatchAutocomplete } from "../component/autocomplete";

const stories = storiesOf("App ts", module);

stories.add("Test", () => {
  const apikey = 'rYGL9L8GzgASw3Qq8AxFbclLsXmCrfbVkJ56kOF9'
  const domainServer = 'https://api.dev.batchdata.com/api/v1/address/autocomplete'
  const [recentSearch, setRecentSearch] = useState([
    {"name": '8300 Apple'},
    {"name": 'Apple St.'},
    {"name": '89001 Alamo'},
    {"name": '58651 Rhame'}
  ])

  const handleError = (e) => {
    console.log('Error while searching: ',e);
  }

  const suggestionList = (data) => {
    console.log('Suggetion List: ', data);
  }

  const onSelect = (data) => {
    console.log('Seleted item: ', data)
    if (data) {
      let newData = [...recentSearch]
      newData.unshift({name: data?.name})
      newData.pop()
      setRecentSearch(newData)
    }
  }

  const searchElement = <Fragment><div className="auto-wrapper">
  <div className="img-wrap" />
    <div className="text-content">
  </div>
</div></Fragment>

  return (
    <div style={{width:420}}>
      <h2>Batch Service React Autocomplete Lib...</h2>
      <p>Start typing to select address:</p>
      <ReactBatchAutocomplete
      placeholder="Enter your address"
      notFoundText="No results found"
      debounce="700"
      apiKey={apikey}
      domainServer={domainServer}
      recentSearch ={recentSearch}
      handleError={(e) => handleError(e)}
      suggestionList={(data) => suggestionList(data)}
      onSelect={(data) => onSelect(data)}
      displayData="name"
      showNotFound={true}
      take={15}
      filterType={['address', 'formatted-street', 'zip']}
    />
    </div>
  );
});
